changes_over_expac: Outputs an interactive animated plot that displays the count...

Description Usage Arguments Value

View source: R/plot_data.R

Description

Outputs an interactive animated plot that displays the count of card for each expansion in H

Usage

1
changes_over_expac(df_cards = get_all_cards(), classifier = "MinionType")

Arguments

df_cards

optional argument. if you already have a data frame generated from any of the get_* functions you may pass it so the function does not have to load a new one. Default set to automatically generate data from get_all_cards function

classifier

a string object that determines what the plot will output, must be "MinionType", "Rarity, or "CardType"

Value

An interactive plotly object that allows the user to view the distribution of the cards released for the selected expansion


kabhatia7/hearrthstone documentation built on March 24, 2021, 5:54 p.m.