get_all_cards: Returns a neat data frame of information about all...

Description Usage Arguments Value

View source: R/get_data.R

Description

Returns a neat data frame of information about all hearthstone cards of a desired filter

Usage

1

Arguments

class

a string filters the cards that return to only be from a specific class in Hearthstone, default is NULL to return all Classes

mana

a string argument, filters the data frame to only include cards of a certain mana cost. Default is NULL which returns cards of all mana costs.

Value

returns a data frame with Name of card, Class, Type, Rarity, Attack, Health, what set it was apart of, durability, armor, and length of card text


kabhatia7/hearrthstone documentation built on March 24, 2021, 5:54 p.m.