get_decks: Returns data frame of cards in a deck using given in game...

Description Usage Arguments Value

View source: R/get_data.R

Description

Returns data frame of cards in a deck using given in game generated deck code

Usage

1
get_decks(deckcode)

Arguments

deckcode

a string of characters that identifies a deck in the game of hearthstone

Value

returns a data frame with with all the cards for a given


kabhatia7/hearrthstone documentation built on March 24, 2021, 5:54 p.m.