get_dummys: create dummy dataframe for decks to be used for...

Description Usage Arguments Value

View source: R/get_data.R

Description

create dummy dataframe for decks to be used for classification

Usage

1
get_dummys(deckcode, deckarchetype)

Arguments

websitecode

a string of characters that identifies a deck in the game of hearthstone

Value

returns a dummy data frame with X columns based on unique copies of cards in the deck plus the mana cost and deck name


kabhatia7/hearrthstone documentation built on March 24, 2021, 5:54 p.m.