get_hsreplay_decks: Uses HSreplay site code to give a data frame of deck...

Description Usage Arguments Value

View source: R/get_data.R

Description

Uses HSreplay site code to give a data frame of deck information

Usage

1
get_hsreplay_decks(websitecode)

Arguments

websitecode

a string of characters that identifies a deck in the game of hearthstone

Value

returns a data frame with Name of card, Class, Type, Rarity, what set it was apart of, and length of card text


kabhatia7/hearrthstone documentation built on March 24, 2021, 5:54 p.m.