Description Usage Arguments Value
main difference between get_spells and get_all_cards is that it returns a data frame with variables only containing values pertaining to spells
1 | get_spells(class = NULL, mana = NULL)
|
class |
a string that filters results to only show specific class in Hearthstone, default is NULL to return all Classes. MUST BE PASSED AS FOLLOWS: "demonhunter" "druid","hunter","mage","paladin","priest","rogue","shaman","warlock", or "warrior" |
mana |
a string argument, filters the data frame to only include cards of a certain mana cost. Default is NULL which returns cards of all mana costs. |
returns a data frame with Name of card, Class, Type, Rarity, what set it was apart of, and length of card text
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.