plot_rarity_stats: Compare different card rarities to see if legendary and epic...

Description Usage Arguments Value

View source: R/plot_data.R

Description

note: there are no neutral spells OR weapons

Usage

1
2
3
4
5
6
7
plot_rarity_stats(
  df_cards = NULL,
  comparison_var,
  cardType = "Minion",
  class = NULL,
  animate = FALSE
)

Arguments

df_cards

optional argument. if you already have a data frame generated from any of the get_* functions you may pass it so the function does not have to load a new one. default is null and will select best get_* function for your query.

comparison_var

string variable argument. Selects a variable to compare the classes by using the get_* functions of the hearrthstone package, get_all_cards for details

cardType

string argument of what data you would like to compare the classes by, minions, spells, weapons, or all types. To compare all types pass NULL. Default set to minions.

class

a string that filters results to only show a specific class in Hearthstone, default is NULL to return all Classes. MUST BE PASSED AS FOLLOWS: "demonhunter" "druid","hunter","mage","paladin","priest","rogue","shaman","warlock", "warrior", "neutral"

animate

animate will allow return an animated plot changing the comparison by the various card sets in the game.

Value

Default outputs an interactive plotly object or a gif if the animate argument is passed as TRUE


kabhatia7/hearrthstone documentation built on March 24, 2021, 5:54 p.m.