token_auth: Regenerate Token

Description Usage Value

View source: R/get_data.R

Description

The blizzard API is a little funky and requires you to regenerate an access token every 24 hours. This function allows us to regenerate the keys within our functions so we don't have to worry about that again For the purposes of this package we will be using my developer key and client secret.

Usage

1

Value

an access token to be used for all other functions


kabhatia7/hearrthstone documentation built on March 24, 2021, 5:54 p.m.