Description Usage Arguments Value
Outputs an interactive animated plot that displays the count of card for each expansion in H
1 | changes_over_expac(df_cards = get_all_cards(), classifier = "MinionType")
|
df_cards |
optional argument. if you already have a data frame generated from any of the get_* functions you may pass it so the function does not have to load a new one. Default set to automatically generate data from get_all_cards function |
classifier |
a string object that determines what the plot will output, must be "MinionType", "Rarity, or "CardType" |
An interactive plotly object that allows the user to view the distribution of the cards released for the selected expansion
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.