Description Usage Arguments Value
Returns a neat data frame of information about all hearthstone cards of a desired filter
1 | get_all_cards(class = NULL, mana = NULL)
|
class |
a string filters the cards that return to only be from a specific class in Hearthstone, default is NULL to return all Classes |
mana |
a string argument, filters the data frame to only include cards of a certain mana cost. Default is NULL which returns cards of all mana costs. |
returns a data frame with Name of card, Class, Type, Rarity, Attack, Health, what set it was apart of, durability, armor, and length of card text
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.