Description Usage Arguments Value
Returns data frame of cards in a deck using given in game generated deck code
1 | get_decks(deckcode)
|
deckcode |
a string of characters that identifies a deck in the game of hearthstone |
returns a data frame with with all the cards for a given
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.