Description Usage Arguments Value
create dummy dataframe for decks to be used for classification
1 | get_dummys(deckcode, deckarchetype)
|
websitecode |
a string of characters that identifies a deck in the game of hearthstone |
returns a dummy data frame with X columns based on unique copies of cards in the deck plus the mana cost and deck name
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.