Description Usage Arguments Value
Uses HSreplay site code to give a data frame of deck information
1 | get_hsreplay_decks(websitecode)
|
websitecode |
a string of characters that identifies a deck in the game of hearthstone |
returns a data frame with Name of card, Class, Type, Rarity, what set it was apart of, and length of card text
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.