Description Usage Arguments Value
main difference between get_minions and get_all_cards is that it returns a data frame with variables only containing values pertaining to minions
1 |
class |
a string that filters results to only show specific class in Hearthstone, default is NULL to return all Classes. MUST BE PASSED AS FOLLOWS: "demonhunter" "druid","hunter","mage","paladin","priest","rogue","shaman","warlock", or "warrior" |
mana |
a string argument, filters the data frame to only include cards of a certain mana cost. Default is NULL which returns cards of all mana costs. |
attack |
a string argument, filters the data frame to only include cards with a specific amount of attack. Default is NULL which returns cards of all attack strengths. |
health |
a string argument, filters the data frame to only include cards with a specific amount of health. Default is NULL which returns cards of all health totals |
returns a data frame with Name of card, Class, Type, Rarity, what set it was apart of, and length of card text
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.