Description Usage Arguments Value
note: there are no neutral spells OR weapons
1 2 3 4 5 6 7 | plot_rarity_stats(
df_cards = NULL,
comparison_var,
cardType = "Minion",
class = NULL,
animate = FALSE
)
|
df_cards |
optional argument. if you already have a data frame generated from any of the |
comparison_var |
string variable argument. Selects a variable to compare the classes by using the get_* functions of the hearrthstone package, get_all_cards for details |
cardType |
string argument of what data you would like to compare the classes by, minions, spells, weapons, or all types. To compare all types pass NULL. Default set to minions. |
class |
a string that filters results to only show a specific class in Hearthstone, default is NULL to return all Classes. MUST BE PASSED AS FOLLOWS: "demonhunter" "druid","hunter","mage","paladin","priest","rogue","shaman","warlock", "warrior", "neutral" |
animate |
animate will allow return an animated plot changing the comparison by the various card sets in the game. |
Default outputs an interactive plotly object or a gif if the animate argument is passed as TRUE
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.