The blizzard API is a little funky and requires you to regenerate an access token every 24 hours. This function allows us to regenerate the keys within our functions so we don't have to worry about that again For the purposes of this package we will be using my developer key and client secret.
1 |
an access token to be used for all other functions
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.